@@ -37,6 +37,10 @@ class PrecomputedAlms(object):
         consider that PySM expects the output of components to be in uK_RJ.
         See more details at https://so-pysm-models.readthedocs.io/en/latest/so_pysm_models/models.html
 
+        Also note that the Alms are clipped to 3*nside-1 to avoid
+        artifacts from high-ell components which cannot be properly represented
+        by a low-nside map.
+
         Parameters
         ----------
         filename : string
@@ -48,7 +52,8 @@ class PrecomputedAlms(object):
         nside : int
             HEALPix NSIDE of the output maps
         from_cl : bool
-            If True, the input file contains C_ell instead of a_lm
+            If True, the input file contains C_ell instead of a_lm,
+            they should provided with the healpy old ordering TT, TE, TB, EE, EB, BB, sorry.
         from_cl_seed : int
             Seed set just before synalm to simulate the alms from the C_ell,
             necessary to set it in order to get the same input map for different runs
@@ -75,8 +80,8 @@ class PrecomputedAlms(object):
             cl = hp.read_cl(self.filename)
             if not self.has_polarization and cl.ndim > 1:
                 cl = cl[0]
-            # using healpy new ordering TT, EE, BB, TE, TB, EB
-            alm = hp.synalm(cl, new=True, verbose=False)
+            # using healpy old ordering TT, TE, TB, EE, EB, BB
+            alm = hp.synalm(cl, new=False, verbose=False)
         else:
             alm = np.complex128(
                 hp.read_alm(
@@ -97,13 +102,22 @@ class PrecomputedAlms(object):
 
     def compute_output_map(self, alm):
 
+        lmax = hp.Alm.getlmax(alm.shape[-1]) # we assume mmax = lmax
         if self.nside is None:
             assert (self.shape is not None) and (self.wcs is not None)
             n_comp = 3 if self.has_polarization else 1
             output_map = enmap.empty((n_comp,) + self.shape[-2:], self.wcs)
             curvedsky.alm2map(alm, output_map, spin=[0, 2], verbose=True)
         elif self.nside is not None:
-            output_map = hp.alm2map(alm, self.nside)
+            if lmax > 3*self.nside-1:
+                clip = np.ones(3*self.nside)
+                if alm.ndim == 1:
+                    alm_clipped = hp.almxfl(alm, clip)
+                else:
+                    alm_clipped = [hp.almxfl(each, clip) for each in alm]
+            else:
+                alm_clipped = alm
+            output_map = hp.alm2map(alm_clipped, self.nside)
         else:
             raise ValueError("You must specify either nside or both of shape and wcs")
         return (output_map << self.input_units).to(
